<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'options_framework_theme'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	// Test data
	$test_array = array(
		'one' => __('One', 'options_framework_theme'),
		'two' => __('Two', 'options_framework_theme'),
		'three' => __('Three', 'options_framework_theme'),
		'four' => __('Four', 'options_framework_theme'),
		'five' => __('Five', 'options_framework_theme')
	);

	// Multicheck Array
	$multicheck_array = array(
		'one' => __('French Toast', 'options_framework_theme'),
		'two' => __('Pancake', 'options_framework_theme'),
		'three' => __('Omelette', 'options_framework_theme'),
		'four' => __('Crepe', 'options_framework_theme'),
		'five' => __('Waffle', 'options_framework_theme')
	);

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );

	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/images/';

	$options = array();

       
	// Defined Stylesheet Paths
// Use get_template_directory_uri if it's a parent theme
	
	$defined_stylesheets = array(
		"0" => "Default", // There is no "default" stylesheet to load
		get_stylesheet_directory_uri() . '/css/blue.css' => "Blue",
		get_stylesheet_directory_uri() . '/css/green.css' => "Green",
		get_stylesheet_directory_uri() . '/css/pink.css' => "Pink"
	);

	$options[] = array(
		'name' => __('General Settings', 'options_framework_theme'),
		'type' => 'heading');
	
	
	$options[] = array(
		'name' => __('Header Image', 'options_framework_theme'),
		'desc' => __('You can upload a header image or paste the image URL.', 'options_framework_theme'),
		'id' => 'header_uploader',
		'type' => 'upload');
	

	$options[] = array( 
	'name' => 'Select a Color Scheme',
		'desc' => 'This is a manually defined list of stylesheets.',
	'id' => 'stylesheet',
	'std' => '0',
	'type' => 'select',
	'options' => $defined_stylesheets );

        /* ---------------------------------------------------------------------------- */
            /* Social Logos */
            /* ---------------------------------------------------------------------------- */
       $options[] =     array(
       'name' => 'Social Icons',
                'type' => 'heading');
                
       $options[] =   array('name' => 'Facebook URL',
                'desc' => 'Enter your Facebook URL if you have one',
                'id' => 'optionsfm_facebook',
                'std' => '',
                'type' => 'text');
             $options[] =       array('name' => 'Twitter URL',
                'desc' => 'Enter your Twitter URL if you have one',
                'id' => 'optionsfm_twitter',
                'std' => '',
                'type' => 'text');
                  $options[] =  array('name' => 'LinkedIn URL',
                'desc' => 'Enter your LinkedIn URL if you have one',
                'id' => 'optionsfm_linked',
                'std' => '',
                'type' => 'text');
                  $options[] =  array('name' => 'RSS Feed URL',
                'desc' => 'Enter your RSS Feed URL if you have one',
                'id' => 'optionsfm_rss',
                'std' => '',
                'type' => 'text');
	



	
	

	$options[] = array(
		'name' => __('Homepage', 'options_framework_theme'),
		'type' => 'heading' );

	/**
	 * For $settings options see:
	 * http://codex.wordpress.org/Function_Reference/wp_editor
	 *
	 * 'media_buttons' are not supported as there is no post to attach items to
	 * 'textarea_name' is set by the 'id' you choose
	 */
	 
	$options[] = array(
		'name' => __('Slogan Text Below Slider', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'top_area',
		'placeholder' => 'Placeholder',
		'type' => 'text');
	
      $options[] = array(
		'name' => __('Slogan Bottom Left Button Link', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'button_left_link',
		'placeholder' => 'Placeholder',
		'type' => 'text');
	$options[] = array(
		'name' => __('Slogan Bottom Left Button Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'sub_area_1',
		'placeholder' => 'Placeholder',
		'type' => 'text');
      
       $options[] = array(
		'name' => __('Slogan Bottom Right Button Link', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'button_right_link',
		'placeholder' => 'Placeholder',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slogan Bottom Right Button Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'sub_area_2',
		'placeholder' => 'Placeholder',
		'type' => 'text');

$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	$options[] = array(
		'name' => __('Column-1-icon', 'options_framework_theme'),
		'desc' => sprintf( __( 'You can also pass settings to the editor.  Read more about wp_editor in <a href="%1$s" target="_blank">the WordPress codex</a>', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'column_1_icon',
		'type' => 'textarea',
		'settings' => $wp_editor_settings );
 
		
    $options[] = array(
		'name' => __('Column-1 Heading', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'column_1_heading',
		'placeholder' => 'Placeholder',
		'type' => 'text');

	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	$options[] = array(
		'name' => __('Column-1 Body Text', 'options_framework_theme'),
		'desc' => __( 'Left Column', 'options_framework_theme' ), 
		'id' => 'column_1',
		'type' => 'textarea',
                'placeholder' => 'Placeholder',
		'settings' => $wp_editor_settings );
         
         $options[] = array(
		'name' => __('Column-1 Button Link', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'blue_button_1',
		'placeholder' => 'Placeholder',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Column-1 Button Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'bluebutton_1_text',
		'placeholder' => 'Placeholder',
		'type' => 'text');
	

$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	$options[] = array(
		'name' => __('Column-2-icon', 'options_framework_theme'),
		'desc' => sprintf( __( 'You can also pass settings to the editor.  Read more about wp_editor in <a href="%1$s" target="_blank">the WordPress codex</a>', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'column_2_icon',
		'type' => 'textarea',
		'settings' => $wp_editor_settings );
 
	 $options[] = array(
		'name' => __('Column-2 Heading', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'column_2_heading',
		'placeholder' => 'Placeholder',
		'type' => 'text');

	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	$options[] = array(
		'name' => __('Column-2 Body Text', 'options_framework_theme'),
		'desc' => sprintf( __( 'You can also pass settings to the editor.  Read more about wp_editor in <a href="%1$s" target="_blank">the WordPress codex</a>', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'column_2',
		'type' => 'textarea',
		'settings' => $wp_editor_settings );
 
          $options[] = array(
		'name' => __('Column-2 Button Link', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'blue_button_2',
		'placeholder' => 'Placeholder',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Column-2 Button Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'bluebutton_2_text',
		'placeholder' => 'Placeholder',
		'type' => 'text');
	
$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	$options[] = array(
		'name' => __('Column-3-icon', 'options_framework_theme'),
		'desc' => sprintf( __( 'You can also pass settings to the editor.  Read more about wp_editor in <a href="%1$s" target="_blank">the WordPress codex</a>', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'column_3_icon',
		'type' => 'textarea',
		'settings' => $wp_editor_settings );
 
	 $options[] = array(
		'name' => __('Column-3 Heading', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'column_3_heading',
		'placeholder' => 'Placeholder',
		'type' => 'text');

		
	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	$options[] = array(
		'name' => __('Column-3 Body Text', 'options_framework_theme'),
		'desc' => sprintf( __( 'You can also pass settings to the editor.  Read more about wp_editor in <a href="%1$s" target="_blank">the WordPress codex</a>', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'column_3',
		'type' => 'textarea',
		'settings' => $wp_editor_settings );
        
         $options[] = array(
		'name' => __('Column-3 Button Link', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'blue_button_3',
		'placeholder' => 'Placeholder',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Column-3 Button Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'bluebutton_3_text',
		'placeholder' => 'Placeholder',
		'type' => 'text');
	
        $options[] = array(
		'name' => __('Bottom Slogan Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'bottom_area',
		'placeholder' => 'Placeholder',
		'type' => 'text');

$options[] = array(
		'name' => __('Slider Settings', 'options_framework_theme'),
		'type' => 'heading');

$options[] = array(
		'name' => __('Slide-1', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'slide_1',
		'placeholder' => 'Placeholder',
		'type' => 'text');

$options[] = array(
		'name' => __('Slide-1 Heading', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'slide_1_heading',
		'placeholder' => 'Placeholder',
		'type' => 'text');

$options[] = array(
		'name' => __('Slide-1 Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'slide_1_text',
		'placeholder' => 'Placeholder',
		'type' => 'text');

$options[] = array(
		'name' => __('Slide-2', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'slide_2',
		'placeholder' => 'Placeholder',
		'type' => 'text');

$options[] = array(
		'name' => __('Slide-2 Heading', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'slide_2_heading',
		'placeholder' => 'Placeholder',
		'type' => 'text');

$options[] = array(
		'name' => __('Slide-2 Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'slide_2_text',
		'placeholder' => 'Placeholder',
		'type' => 'text');



$options[] = array(
		'name' => __('Slide-3', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'slide_3',
		'placeholder' => 'Placeholder',
		'type' => 'text');

$options[] = array(
		'name' => __('Slide-3 Heading', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'slide_3_heading',
		'placeholder' => 'Placeholder',
		'type' => 'text');

$options[] = array(
		'name' => __('Slide-3 Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'slide_3_text',
		'placeholder' => 'Placeholder',
		'type' => 'text');
	
	$options[] = array(
		'name' => __('Footer Settings', 'options_framework_theme'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Left Footer Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'left_footer_text',
		'placeholder' => 'Placeholder',
		'type' => 'textarea');
 

        $options[] = array(
		'name' => __('Right Footer Text', 'options_framework_theme'),
		'desc' => __('A text input field with an HTML5 placeholder.', 'options_framework_theme'),
		'id' => 'right_footer_text',
		'placeholder' => 'Placeholder',
		'type' => 'textarea');
	
		
	
	return $options;
	
	


}